InferredAction

Enum InferredAction 

pub enum InferredAction {
    FlagContradiction {
        existing: MemoryId,
        new: MemoryId,
        reason: String,
    },
    MarkObsolete {
        memory: MemoryId,
        superseded_by: MemoryId,
    },
    InvalidateMemory {
        memory: MemoryId,
        superseded_by: MemoryId,
        valid_until: u64,
    },
    UpdateContent {
        memory: MemoryId,
        new_content: String,
        reason: String,
    },
    CreateEdge {
        source: MemoryId,
        target: MemoryId,
        edge_type: EdgeType,
        weight: f32,
    },
    UpdateConfidence {
        memory: MemoryId,
        new_confidence: f32,
    },
    PropagateBeliefChange {
        root: MemoryId,
        delta: f32,
    },
}

Variants



FlagContradiction

Fields

existing: MemoryId
reason: String


MarkObsolete

Fields

memory: MemoryId
superseded_by: MemoryId


InvalidateMemory

Set valid_until on the old memory instead of deleting it.

Fields

memory: MemoryId
superseded_by: MemoryId
valid_until: u64


UpdateContent

Update the content of an existing memory with merged information.

Fields

memory: MemoryId
new_content: String
reason: String


CreateEdge

Fields

source: MemoryId
target: MemoryId
edge_type: EdgeType
weight: f32


UpdateConfidence

Fields

memory: MemoryId
new_confidence: f32


PropagateBeliefChange

Fields

delta: f32