WriteInferenceEngine

Struct WriteInferenceEngine 

pub struct WriteInferenceEngine { /* private fields */ }

Implementations

Source

impl WriteInferenceEngine

pub fn new() -> Self

pub fn with_config(config: WriteInferenceConfig) -> Self

pub fn infer_on_write( &self, new_memory: &MemoryNode, existing_memories: &[MemoryNode], existing_edges: &[(MemoryId, MemoryId, EdgeType)], ) -> Vec<InferredAction>

pub async fn infer_on_write_with_llm<J: LlmJudge>( &self, new_memory: &MemoryNode, existing_memories: &[MemoryNode], existing_edges: &[(MemoryId, MemoryId, EdgeType)], llm: &CognitiveLlmService<J>, ) -> Vec<InferredAction>

LLM enhanced write inference. Uses the CognitiveLlmService when available to make smarter invalidation and contradiction decisions. Falls back to cosine similarity heuristics for moderate similarity (Related edges) and correction handling.